@@ -379,17 +379,20 @@ amsubset<-function(x,idvars,p2s,ts,cs,priors=NULL,
     cat("Variables used: ", theta.names,"\n")
   }
 
-  AMr1<-is.na(x)
-  flag<-rowSums(AMr1)==ncol(x)
+  AMr1 <- is.na(x)
+  flag <- rowSums(AMr1)==ncol(x)
 
-  if (max(flag)==1){
-    blanks<-1:nrow(x)
-    blanks<-blanks[flag]
-    x<-x[!flag,]
+  if (max(flag) == 1){
+    blanks <- which(flag)
+    x <- x[!flag,]
     if (!is.null(priors)) {
       priors <- priors[!(priors[,1] %in% blanks),]
-      priors[,1] <- priors[,1,drop=FALSE] - colSums(sapply(priors[,1,drop=FALSE],">",blanks))
-
+      if (length(blanks) == 1) {
+        row.adjust <- 1 * (priors[, 1, drop = FALSE] > blanks)
+      } else {
+        row.adjust <- colSums(sapply(priors[, 1, drop = FALSE],">",blanks))
+      }
+      priors[,1] <- priors[,1,drop=FALSE] - row.adjust
     }
 
 
@@ -521,8 +524,8 @@ scalecenter<-function(x,priors=NULL,bounds=NULL){
   stdvx<-apply(x,2,sd,na.rm=TRUE)
   no.obs <- colSums(!is.na(x)) == 0
   if (!is.null(priors)) {
-    meanx[no.obs] <- unlist(tapply(priors[,3],priors[,2],mean))[order(unique(priors[,2]))]
-    stdvx[no.obs] <-  unlist(tapply(priors[,3],priors[,2],sd))[order(unique(priors[,2]))]
+    meanx[no.obs] <- 0#unlist(tapply(priors[,3],priors[,2],mean))[order(unique(priors[,2]))]
+    stdvx[no.obs] <- 1#unlist(tapply(priors[,3],priors[,2],sd))[order(unique(priors[,2]))]
   }
   x.ztrans<-(x-(ones %*% meanx))/(ones %*% stdvx)
   if (!is.null(priors)){
@@ -668,7 +671,7 @@ amelia.prep <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
                         leads=NULL,intercs=FALSE,sqrts=NULL,
                         lgstc=NULL,noms=NULL,incheck=TRUE,ords=NULL,collect=FALSE,
                         arglist=NULL, priors=NULL,var=NULL,autopri=0.05,bounds=NULL,
-                        max.resample=NULL, overimp = NULL, emburn=NULL) {
+                        max.resample=NULL, overimp = NULL, emburn=NULL, boot.type=NULL) {
 
 
   code <- 1
@@ -704,6 +707,7 @@ amelia.prep <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
     bounds    <- arglist$bounds
     overimp   <- arglist$overimp
     emburn    <- arglist$emburn
+    boot.type <- arglist$boot.type
     max.resample <- arglist$max.resample
   }
 
@@ -725,7 +729,8 @@ amelia.prep <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
                        intercs = intercs, noms = numopts$noms,
                        startvals = startvals, ords = numopts$ords, collect =
                        collect,  bounds=bounds,
-                       max.resample=max.resample, overimp = overimp, emburn=emburn)
+                       max.resample=max.resample, overimp = overimp, emburn=emburn,
+                       boot.type=boot.type)
     #check.call <- match.call()
     #check.call[[1]] <- as.name("amcheck")
     #checklist <- eval(check.call, parent.frame())
@@ -749,7 +754,7 @@ amelia.prep <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
                 noms=numopts$noms, ords=numopts$ords,
                 priors=priors, autopri=autopri, bounds=bounds,
                 max.resample=max.resample, startvals=startvals,
-                overimp = overimp, emburn=emburn)
+                overimp = overimp, emburn=emburn, boot.type=boot.type)
                                                                                 #change 2
 
 
